# opsipxeconfd is part of the device management solution opsi http://www.opsi.org
# Copyright (c) 2013-2025 uib GmbH <info@uib.de>
# All rights reserved.
# License: AGPL-3.0-only

"""
:copyright: uib GmbH <info@uib.de>
This file is part of opsi - https://www.opsi.org

:license: GNU Affero General Public License version 3
See LICENSES/README.md for more Information
"""

import os
import sys
import warnings

from opsicommon.logging import logger

if getattr(sys, "frozen", False):
	# Disable warnings if frozen
	warnings.simplefilter("ignore", ResourceWarning)
	warnings.simplefilter("ignore", DeprecationWarning)
else:
	package_base = os.path.dirname(__file__)
	if package_base in sys.path:
		sys.path.remove(package_base)

from opsipxeconfd.opsipxeconfdinit import OpsipxeconfdInit  # noqa: E402


def main() -> None:
	"""
	Main method.

	This method controls the execution flow of the opsipxeconfd.
	"""
	try:
		OpsipxeconfdInit()
	except SystemExit:
		pass
	except KeyboardInterrupt:
		print("Interrupted", file=sys.stderr)
		sys.exit(1)
	except Exception as err:
		logger.error(err, exc_info=True)
		print(f"ERROR: {err}", file=sys.stderr)
		sys.exit(1)


if __name__ == "__main__":
	main()
